@@ -1,4 +1,4 @@
-# Copyright 2010-2017, Damian Johnson and The Tor Project
+# Copyright 2010-2019, Damian Johnson and The Tor Project
 # See LICENSE for licensing information
 
 """
@@ -169,6 +169,8 @@ Dimensions = collections.namedtuple('Dimensions', ['width', 'height'])
 
 def conf_handler(key, value):
   if key == 'color_override':
+    value = stem.util.str_tools._to_camel_case(value)
+
     if value not in Color and value != 'None':
       raise ValueError('"%s" isn\'t a valid color' % value)
   elif key == 'max_line_wrap':
@@ -316,6 +318,18 @@ def _handle_key(textbox, key):
       textbox.win.move(y, msg_length - 1)  # if we're in the content then move to the end
     elif key == curses.KEY_RIGHT and x < msg_length - 1:
       textbox.win.move(y, x + 1)  # only move cursor if there's content after it
+  elif key == curses.KEY_DC:
+    # Delete key. Remove the character after the cursor if there is one.
+
+    y, x = textbox.win.getyx()
+    content = textbox.gather()
+
+    if x < len(content):
+      content = content[:x] + content[x + 1:]
+      textbox.win.clear()
+      textbox.win.addstr(y, 0, content)
+
+    textbox.win.move(y, x)  # revert cursor to its prior position
   elif key == 410:
     # if we're resizing the display during text entry then cancel it
     # (otherwise the input field is filled with nonprintable characters)
@@ -747,6 +761,8 @@ def draw(func, left = 0, top = 0, width = None, height = None, background = None
     curses_subwindow.refresh()
 
     return subwindow_dimensions
+  except curses.error:
+    return  # raw curses access, such as subwin, can raise in edge cases such as resizing
   finally:
     CURSES_LOCK.release()
 
